@@ -219,7 +219,7 @@ wnck_selector_get_window_name (WnckWindow *window)
   else
     name = g_strdup (const_name);
 
-  if (wnck_window_demands_attention (window))
+  if (wnck_window_or_transient_demands_attention (window))
     {
       return_value = g_strdup_printf ("<b>%s</b>", name);
       g_free (name);
@@ -358,14 +358,19 @@ static void
 wnck_selector_activate_window (WnckWindow *window)
 {
   WnckWorkspace *workspace;
+  guint32 timestamp;
 
+  /* We're in an activate callback, so gtk_get_current_time() works... */
+  timestamp = gtk_get_current_event_time ();
+
+  /* FIXME: THIS IS SICK AND WRONG AND BUGGY.  See the end of
+   * http://mail.gnome.org/archives/wm-spec-list/2005-July/msg00032.html
+   * There should only be *one* activate call.
+   */
   workspace = wnck_window_get_workspace (window);
-  wnck_workspace_activate (workspace);
+  wnck_workspace_activate (workspace, timestamp);
 
-  if (wnck_window_is_minimized (window))
-    wnck_window_unminimize (window);
-
-  wnck_window_activate (window);
+  wnck_window_activate (window, timestamp);
 }
 
 #define SELECTOR_MAX_WIDTH 50   /* maximum width in characters */
